@@ -1,6 +1,6 @@
 package App::PerlWatcher::Engine;
 {
-  $App::PerlWatcher::Engine::VERSION = '0.18_3'; # TRIAL
+  $App::PerlWatcher::Engine::VERSION = '0.14'; # TRIAL
 }
 # ABSTRACT: Creates Watchers and lets them  notify Frontend with their's Statuses
 
@@ -11,19 +11,17 @@ use warnings;
 use AnyEvent;
 use Carp;
 use Class::Load ':all';
-use Smart::Comments -ENV;
+use Data::Dumper;
+use Devel::Comments;
 use File::Spec;
-use List::MoreUtils qw/first_index/;
 use Moo;
-use Path::Tiny;
+use Path::Class qw(file);
 
 use App::PerlWatcher::Shelf;
 use App::PerlWatcher::Util::Bootstrap qw/get_home_dir/;
 use App::PerlWatcher::Util::Storable qw/freeze thaw/;
 
 
-
-
 has 'frontend'          => ( is => 'rw');
 
 
@@ -33,16 +31,13 @@ has 'backend'           => ( is => 'ro', required => 1);
 
 
 has 'statuses_file'     => ( is => 'ro', default => sub {
-        return path(File::Spec->catfile(get_home_dir(), "statuses-shelf.data"));
+        return file(File::Spec->catfile(get_home_dir(), "statuses-shelf.data"));
     });
 
 
 has 'watchers'          => ( is => 'lazy');
 
 
-has 'polling_watchers' => ( is => 'ro', default => sub{ [] });
-
-
 has 'watchers_order'    => ( is => 'lazy');
 
 
@@ -52,33 +47,13 @@ sub _build_watchers {
     my $self = shift;
     my $config = $self->config;
     my @r;
-    my $poll_callback = sub {
-        my $w = shift;
-        push @{ $self->polling_watchers }, $w;
-        $self->frontend->poll($w);
-    };
-    my $engine_callback = sub {
-        my $status = shift;
-        my $w_idx = first_index { $_->unique_id eq $status->watcher->unique_id }
-            @{ $self->polling_watchers };
-        splice( @{ $self->polling_watchers }, $w_idx, 1);
-        AnyEvent::postpone {
-            $self->frontend->update($status);
-        };
-    };
     for my $watcher_definition ( @{ $config -> {watchers} } ) {
         my ($class, $watcher_config )
             = @{ $watcher_definition }{ qw/class config/ };
         my $watcher;
         eval {
             load_class($class);
-            $watcher = $class->new(
-                engine_config => $config,
-                callback      => $engine_callback,
-                poll_callback => $poll_callback,
-                %$watcher_config
-            );
-            $watcher->callback($engine_callback);
+            $watcher = $class->new( engine_config => $config, %$watcher_config );
             push @r, $watcher;
         };
         carp "Error creating watcher $class : $@" if $@;
@@ -113,7 +88,16 @@ sub BUILD {
 
 sub start {
     my $self = shift;
-    $_->start for ( @{ $self->watchers } );
+    for my $w ( @{ $self->watchers } ) {
+        $w->start(
+            sub {
+                my $status = shift;
+                AnyEvent::postpone {
+                    $self->frontend->update($status);
+                };
+            }
+        );
+    }
     # actually trigger watchers
     $self->backend->start_loop;
 }
@@ -138,7 +122,6 @@ sub sort_statuses {
     ];
 }
 
-
 1;
 
 __END__
@@ -151,7 +134,7 @@ App::PerlWatcher::Engine - Creates Watchers and lets them  notify Frontend with
 
 =head1 VERSION
 
-version 0.18_3
+version 0.14
 
 =head1 SYNOPSIS
 
@@ -189,21 +172,6 @@ version 0.18_3
                 },
             },
         },
-        {
-            class => 'App::PerlWatcher::Watcher::GenericExecutor',
-            config => {
-                command       => "/bin/ls",
-                arguments     => ["-1a", "/tmp/"],
-                frequency     => 60,
-                timeout       => 5,
-                # filtering "." and ".." files
-                filter        => sub { ($_ !~ /^\.{1,2}$/) && (/\S+/) },
-                rules         => [
-            	    warn  => sub { any { /strange_file.txt/ } @_ },
-                ],
-            }
-        },
-
     ],
  };
 
@@ -223,13 +191,6 @@ version 0.18_3
  # info
  # warn
  # ...
- # or you'll get warn if strange_file.txt suddendly appears
- # in /tmp
-
-=head1 DESCRIPTION
-
-The more detailed description of PerlWatcher application can be found here:
-L<https://github.com/basiliscos/perl-watcher>.
 
 =head1 ATTRIBUTES
 
@@ -252,10 +213,6 @@ $HOME/.perl-watcher/statuses-shelf.data
 An array_ref of Watcher instances. Watchers order is the same as it was
 defined in config
 
-=head2 polling_watchers
-
-An array_ref of Watcher instances, which currently do poll of external resource
-
 =head2 watchers_order
 
 Return an map "watcher to watcher order".
@@ -282,14 +239,6 @@ and shelf)
 Helper method which sorts statuses in accordance with theirs watchers
 order
 
-=head1 CREDITS
-
-=over 2
-
-Alexandr Ciornii
-
-=back
-
 =head1 AUTHOR
 
 Ivan Baidakou <dmol@gmx.com>
