@@ -1,6 +1,6 @@
 package App::PerlWatcher::Frontend;
 {
-  $App::PerlWatcher::Frontend::VERSION = '0.18_3'; # TRIAL
+  $App::PerlWatcher::Frontend::VERSION = '0.14'; # TRIAL
 }
 # ABSTRACT: The base role to which will be notified of updated watcher statuses. 
 
@@ -15,9 +15,6 @@ use Moo::Role;
 requires 'update';
 
 
-requires 'poll';
-
-
 has 'engine'       => ( is => 'ro', required => 1 );
 
 1;
@@ -32,7 +29,7 @@ App::PerlWatcher::Frontend - The base role to which will be notified of updated
 
 =head1 VERSION
 
-version 0.18_3
+version 0.14
 
 =head1 ATTRIBUTES
 
@@ -42,18 +39,10 @@ Holds reference to Engine
 
 =head1 METHODS
 
-=head2 update
+=head2 start
 
 The update method will be called with Status, which has been updated.
 
- $frontend->update($status);
-
-=head2 poll
-
-The poll method will be called when watcher is polling external source
-
- $frontend->poll($watcher);
-
 =head1 AUTHOR
 
 Ivan Baidakou <dmol@gmx.com>
