@@ -1,6 +1,6 @@
 package App::PerlWatcher::Status;
 {
-  $App::PerlWatcher::Status::VERSION = '0.18_3'; # TRIAL
+  $App::PerlWatcher::Status::VERSION = '0.14'; # TRIAL
 }
 # ABSTRACT: Represents the result of single watcher poll
 
@@ -9,7 +9,8 @@ use strict;
 use warnings;
 
 use Carp;
-use Smart::Comments -ENV;
+use Data::Dumper;
+use Devel::Comments;
 use Moo;
 
 use App::PerlWatcher::Level;
@@ -101,7 +102,7 @@ App::PerlWatcher::Status - Represents the result of single watcher poll
 
 =head1 VERSION
 
-version 0.18_3
+version 0.14
 
 =head1 ATTRIBUTES
 
