@@ -1,6 +1,6 @@
 package App::PerlWatcher::Util::Bootstrap;
 {
-  $App::PerlWatcher::Util::Bootstrap::VERSION = '0.18_3'; # TRIAL
+  $App::PerlWatcher::Util::Bootstrap::VERSION = '0.14'; # TRIAL
 }
 # ABSTRACT: Collection of various helper-methods to boostrap PerlWatcher
 
@@ -13,7 +13,7 @@ use Class::Load ':all';
 use File::Copy;
 use File::ShareDir::ProjectDistDir ':all';
 use File::Spec;
-use Path::Tiny;
+use Path::Class qw(file dir);
 
 use parent qw/Exporter/;
 
@@ -30,7 +30,7 @@ sub engine_config {
 
 sub config {
     my ($file) = @_;
-    my $content_config = path($file)->slurp_utf8;
+    my $content_config = file($file)->slurp(iomode => '<:encoding(UTF-8)');
     my $config = eval "no warnings; $content_config ";
     croak("error in config: $@") if $@ ;
     return $config;
@@ -49,7 +49,7 @@ sub get_home_file {
 
 
 sub get_home_dir {
-    my $home = path(File::Spec->catfile($ENV{'HOME'}, '.perl-watcher'));
+    my $home = dir(File::Spec->catfile($ENV{'HOME'}, '.perl-watcher'));
     if ( not-X $home ) {
         mkdir $home or croak("can't create $home : $!");
     }
@@ -68,7 +68,7 @@ App::PerlWatcher::Util::Bootstrap - Collection of various helper-methods to boos
 
 =head1 VERSION
 
-version 0.18_3
+version 0.14
 
 =head1 METHODS
 
