@@ -1,6 +1,6 @@
 package App::PerlWatcher::Util::Storable;
 {
-  $App::PerlWatcher::Util::Storable::VERSION = '0.18_3'; # TRIAL
+  $App::PerlWatcher::Util::Storable::VERSION = '0.14'; # TRIAL
 }
 # ABSTRACT: Used to freeze/thaw PerlWatcher status (watcher memories and shelf of statuses)
 
@@ -8,7 +8,7 @@ use 5.12.0;
 use strict;
 use warnings;
 
-use Smart::Comments -ENV;
+use Devel::Comments;
 use Storable;
 
 use App::PerlWatcher::Engine;
@@ -77,7 +77,7 @@ App::PerlWatcher::Util::Storable - Used to freeze/thaw PerlWatcher status (watch
 
 =head1 VERSION
 
-version 0.18_3
+version 0.14
 
 =head1 AUTHOR
 
