@@ -1,6 +1,6 @@
 package App::PerlWatcher::Watcher::Weather;
 {
-  $App::PerlWatcher::Watcher::Weather::VERSION = '0.18_3'; # TRIAL
+  $App::PerlWatcher::Watcher::Weather::VERSION = '0.14'; # TRIAL
 }
 # ABSTRACT: Weather watches based around api.yr.no. Currenlty monitors only temperature and does no any notifications / level alerts.
 
@@ -11,7 +11,8 @@ use utf8;
 
 use App::PerlWatcher::EventItem;
 use Carp;
-use Smart::Comments -ENV;
+use Devel::Comments;
+use HTTP::Date;
 use Moo;
 use XML::XPath;
 
@@ -20,7 +21,6 @@ our $T_UNITS = {
 };
 
 
-
 has 'latitude'          => ( is => 'ro', required => 1);
 
 
@@ -48,7 +48,7 @@ sub _build_url {
 
 sub description {
     my $self = shift;
-    my $desc = "";
+    my $desc = "Weather ";
     my %data = %{ $self->data // {} };
     if ( %data ) {
         $desc .= join(q{, } ,
@@ -90,21 +90,7 @@ App::PerlWatcher::Watcher::Weather - Weather watches based around api.yr.no. Cur
 
 =head1 VERSION
 
-version 0.18_3
-
-=head1 SYNOPSIS
-
- # use the following config for Engine:
-        {
-            class => 'App::PerlWatcher::Watcher::Weather',
-            config => {
-                describer   => sub { "Weather in Minsk: " . $_[0] },
-                latitude    => 53.54,
-                longitude   => 27.34,
-                frequency   => 1800,
-                timeout     => 15,
-            },
-        },
+version 0.14
 
 =head1 ATTRIBUTES
 
