@@ -1,6 +1,6 @@
 package App::PerlWatcher::WatcherMemory;
 {
-  $App::PerlWatcher::WatcherMemory::VERSION = '0.18_3'; # TRIAL
+  $App::PerlWatcher::WatcherMemory::VERSION = '0.14'; # TRIAL
 }
 # ABSTRACT: Represents watcher memory, which can be persisted (detached) from Watcher
 
@@ -21,12 +21,6 @@ has 'thresholds_map'    => ( is => 'ro', required => 1);
 has 'last_level'        => ( is => 'rw', default => sub { LEVEL_NOTICE; } );
 
 
-has 'active' => (is => 'rw', default => sub { 1 } );
-
-
-has 'data' => (is => 'rw', default => sub { {}; });
-
-
 sub interpret_result {
     my ($self, $result) = @_;
     my $threshold_map = $self -> thresholds_map;
@@ -71,7 +65,7 @@ App::PerlWatcher::WatcherMemory - Represents watcher memory, which can be persis
 
 =head1 VERSION
 
-version 0.18_3
+version 0.14
 
 =head1 ATTRIBUTES
 
@@ -92,17 +86,6 @@ which level of severity it is. It looks like:
 
 Represents last emitted watcher level. 
 
-=head2 active
-
-Represents whether the watcher is active or not
-
-=head2 'data'
-
-An hashref of arbitrary to be stored within memory from front-end application, e.g.:
-collapsed/expanded state, viewed time etc.
-
-Storing of coderef's isn't supported.
-
 =head1 METHODS
 
 =head2 interpret_result
